@@ -44,19 +44,22 @@ from data_science_helper.model import custom_bagging__lgb_model as cb_lgb_model
 #import model.scale_pos_weight__lgb_model as spw_lgb_model
 #import model.custom_bagging__lgb_model as cb_lgb_model
 
-def modelar_clasificacion_binaria(strategy, X_train=None,y_train=None,X_test=None,y_test=None,params=None,url=None,print_consola=True):
+def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=None,y_test=None,params=None,metric='average_precision',api="train_api",url=None,print_consola=True):
     start = time.time()
+            
+    args = {'X_train':X_train, 'y_train': y_train, 'X_test': X_test, 'y_test': y_test, 'params':params, "metric":metric,"api":api , "url":url }    
+    
     if (strategy=="neg_bagging_fraction__lgb_model"):
-        model , predicted_probas   = nbf_lgb_model.modelar(X_train,y_train,X_test,y_test,params,url)
+        model , y_prob_uno   = nbf_lgb_model.modelar(**args)
     if (strategy=="scale_pos_weight__lgb_model"):
-        model , predicted_probas   = spw_lgb_model.modelar(X_train,y_train,X_test,y_test,params,url)
+        model , y_prob_uno   = spw_lgb_model.modelar(**args)
     if (strategy=="custom_bagging__lgb_model"):
-        model , predicted_probas   = cb_lgb_model.modelar(X_train,y_train,X_test,y_test,url)
+        model , y_prob_uno   = cb_lgb_model.modelar(X_train,y_train,X_test,y_test,url)
 
-    kpis = generar_reporte(model,predicted_probas,X_test,y_test,url,print_consola)
+    kpis = generar_reporte(model,y_prob_uno,X_test,y_test,url,print_consola)
     print("Time elapsed: ", time.time() - start)
     
-    return model , predicted_probas  , kpis
+    return model , y_prob_uno  , kpis
 
 
 def modelar_clasificacion_binaria_rscv(strategy, X_train,y_train=None,X_test=None,y_test=None,score_rs=None,params=None,param_dist=None, n_iter=None,n_jobs=None,url=None,print_consola=True):
@@ -77,12 +80,12 @@ def modelar_clasificacion_binaria_rscv(strategy, X_train,y_train=None,X_test=Non
     return results, model , predicted_probas, params, best_params ,kpis
     
 
-def generar_reporte(model,predicted_probas, X_test, y_test,url,print_consola):    
-    kpis = hp.print_kpis_rendimiento_modelo(y_test,predicted_probas,url,print_consola)   
+def generar_reporte(model,y_prob_uno, X_test, y_test,url,print_consola):    
+    kpis = hp.print_kpis_rendimiento_modelo(y_test,y_prob_uno,url,print_consola)   
     if  isinstance(model, list)==False:
         if (print_consola):
             hp.print_shap_plot(model, X_test, url)      
-    g.generate_summary_evaluation(X_test,predicted_probas,y_test,url) 
+    g.generate_summary_evaluation(X_test,y_prob_uno,y_test,url) 
     return kpis
     
     
